rule filter_length:
    input:
        fasta_file = f"{frangipane_obj.path_contigs}/{{sample_name}}-{{ref_name}}/{{sample_name}}-{{ref_name}}-contigs.fa"
    output:
        fasta_file = f"{frangipane_obj.path_filtered_contigs}/{{sample_name}}-{{ref_name}}-contigs.fa"
    log:
        output = f"{frangipane_obj.path_logs}/post-abyss/filtered-{{sample_name}}-{{ref_name}}.o",
        error = f"{frangipane_obj.path_logs}/post-abyss/filtered-{{sample_name}}-{{ref_name}}.e"
    params:
        length = frangipane_obj.get_config_value("CONTIGS","minLength")
    message:
        f"""--------------------
-Running {{rule}}
|-- Input:
|   - fasta files: {{frangipane_obj.path_contigs}}
|-- Output:
|   - fasta dir: {{frangipane_obj.path_filtered_contigs}}
|-- Other infos:
|   - LOG output : {{log.output}} 
--------------------
"""
    run:

        from Bio import SeqIO

        try:
            with open(output.fasta_file, 'w') as o:
                for seq in SeqIO.parse(input.fasta_file, "fasta"):
                        if len(seq) >= params.length:
                            o.write('>' + str(seq.description) + '\n')
                            txt = str(seq.seq)
                            lines = txt.split('\n')
                            for line in lines:
                                if len(line) > 0:
                                    if line[0] == '>':
                                        o.write(line + '\n')
                                    else:
                                        o.write(gs.format_60(line) + '\n')
        except Exception as e:
            raise ValueError(f"Error during filtering on contig legth: {e}")