rule merge_flagstat:
    input:
        stat_files= expand(rules.samtools_flagstat.output.stat_file, sample_name=SAMPLES, ref_name=REF)
    output:
        stat_file = f"{frangipane_obj.path_stat_sum}/01_all_flagstat-stats-ref_bam.csv"
    log:
        output = f"{frangipane_obj.path_logs}/report/merging_flagstat.o",
        error = f"{frangipane_obj.path_logs}/report/merging_flagstat.e"
    message:
         f"""--------------------
-Running {{rule}}
|-- Input:
|   - Bam stat directory : {{frangipane_obj.path_bam}}
|-- Output:
|   - Stat file: {{output.stat_file}}
|-- Other infos:
|   - LOG output : {{log.output}}
--------------------
"""
    run:
        if os.path.exists(output.stat_file):
            os.remove(output.stat_file)

        f = open(output.stat_file, "w")
        header = "sample,MAPPED,PAIRED,UNMAPPED"
        f.write(header)

        for file_name in input.stat_files:

            sample = os.path.basename(file_name).split('.')[0]
            newLine = f"\n{sample}"

            with open(file_name, "r") as stat:
                for line in stat:
                    line = line.rstrip()

                    if ('mapped (' in line and not 'primary' in line) or 'paired (' in line  or 'singleton' in line:
                        # print(line.split('(')[1].split('%')[0])
                        newLine += f",{line.split('(')[1].split('%')[0]}"

            f.write(newLine)

        f.close()
